from .methods import on, call
from .structures import EventCall, EventHandler, EventSupport
from .exceptions import UncancellableEvent
from .event_space import EventSpace

__name__ = "pyding"
__version__ = "1.5.1"